@@ -2,7 +2,7 @@ package Test2::Plugin::DieOnFail;
 use strict;
 use warnings;
 
-our $VERSION = '0.000038';
+our $VERSION = '0.000041';
 
 use Test2::API qw/test2_add_callback_context_release/;
 
@@ -33,7 +33,7 @@ Test2::Plugin::DieOnFail - Automatically die on the first test failure.
 
 This module will die after the first test failure. This will prevent your tests
 from continuing. The exception is thrown when the context is released, that is
-it will run when the test function you are using, such as C<ok()>, returns;
+it will run when the test function you are using, such as C<ok()>, returns.
 This gives the tools the ability to output any extra diagnostics they may need.
 
 =head1 SYNOPSIS
